@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: biff.cc,v $
-// Revision      : $Revision: 1.44 $
-// Revision date : $Date: 2005/04/07 14:46:52 $
+// Revision      : $Revision: 1.44.2.2 $
+// Revision date : $Date: 2005/12/04 20:05:04 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -252,7 +252,8 @@ Biff::replace (Mailbox *from, Mailbox *to)
 		}
 	g_mutex_unlock (mutex_);
 
-	if ((inserted) && (!GTK_WIDGET_VISIBLE(preferences_->get())))
+	if ((inserted) && (!preferences_
+					   || !GTK_WIDGET_VISIBLE(preferences_->get())))
 		inserted->threaded_start (3);	
 	return inserted;
 }
@@ -387,32 +388,39 @@ Biff::option_update (Option *option)
  *  with changed default values will be converted if possible. If the option
  *  still has the old default value this is no problem, otherwise we might
  *  give a warning message so the user can do this manually.
+ *
+ *  If the config file belongs to a newer version of gnubiff, no conversion
+ *  will be done!
  */
 void 
 Biff::upgrade_options (void)
 {
+	// Get version of gnubiff binary
+	guint gnubiff_version = Support::version_to_integer (PACKAGE_VERSION);
+
 	// Get config file version and reset internal version
 	std::string config_version = value_string ("version");
-	gint version = -1;
-	if (config_version == "0") {
+	guint version = 0;
+	if (config_version == "0")
 		config_version = "<=2.1.1";
-		version = 0;
-	}
+	else
+		version = Support::version_to_integer (config_version);
 	reset ("version");
+
+	// Check for newer version config file
+	if (version > gnubiff_version) {
+// Note: No new strings in gnubiff 2.1.x
+//		g_warning (_("Loaded config file from newer gnubiff version \"%s\"."),
+//					 config_version.c_str ());
+		return; 
+	}
+	if (version == gnubiff_version)
+		return;
+
+	// Config file belongs to an older version of gnubiff
 	g_warning (_("Loaded config file from old gnubiff version \"%s\"."),
 			   config_version.c_str ());
 	g_message (_("Trying to convert all options."));
-	if (version < 0) {
-		std::replace (config_version.begin(), config_version.end(), '.', ' ');
-		std::stringstream tmpstr (config_version);
-		guint tmp;
-		tmpstr >> tmp;
-		version  = 1000*1000*tmp;
-		tmpstr >> tmp;
-		version += 1000*tmp;
-		tmpstr >> tmp;
-		version += tmp;
-	}
 
 	// Store options that need manual conversion
 	std::string options_bad;
