@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: imap4.cc,v $
-// Revision      : $Revision: 1.124 $
-// Revision date : $Date: 2005/03/29 15:29:05 $
+// Revision      : $Revision: 1.127 $
+// Revision date : $Date: 2005/04/11 21:55:00 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -117,6 +117,7 @@ Imap4::threaded_start (guint delay)
 void 
 Imap4::start (void)
 {
+	// Is there already someone watching this mailbox?
 	if (!g_mutex_trylock (monitor_mutex_))
 		return;
 
@@ -665,14 +666,12 @@ Imap4::command_fetchuid (std::set<guint> msn) throw (imap_err)
 	if (!msn.size())
 		return uid;
 
-	std::stringstream ss;
-	std::set<guint>::iterator i = msn.begin();
-	ss << *(i++);
-	while (i != msn.end())
-		ss << "," << *(i++);
+	std::string msnstr;
+	msnstr = vector_to_numbersequence<std::set<guint>::iterator>(msn.begin (),
+				msn.end (), ",", ":");
 
 	// Send command
-	sendline ("FETCH " + ss.str () + " (UID)");
+	sendline ("FETCH " + msnstr + " (UID)");
 
 	// Get all untagged responses that are of interest
 	std::set<guint>::size_type cnt = msn.size() + 1; // prevent DoS
@@ -1203,7 +1202,7 @@ Imap4::parse_bodystructure (std::string structure, PartInfo &partinfo,
 		}
 
 		// Alphanumerical character
-		if (g_ascii_isalnum (c))	{
+		if (g_ascii_isalnum (c)) {
 			if ((multipart) && (nestlevel == 0))
 				return false;
 			if (!multipart)
