@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: local.h,v $
-// Revision      : $Revision: 1.7 $
-// Revision date : $Date: 2005/04/13 12:01:03 $
+// Revision      : $Revision: 1.9 $
+// Revision date : $Date: 2005/06/30 21:23:05 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -34,6 +34,7 @@
 
 #include "mailbox.h"
 #include <fam.h>
+#include <glib.h>
 #include <string>
 
 #define LOCAL(x)					((Local *)(x))
@@ -50,6 +51,22 @@ protected:
 	FAMConnection   fam_connection_;
 	FAMRequest      fam_request_;
 	FAMEvent        fam_event_;
+	/**
+	 *  This boolean indicates whether a FAM connection is being open or not.
+	 *  It must only be read or changed when the fam_mutex_ is locked by the
+	 *  thread.
+	 */
+	gboolean        fam_is_open_;
+	/**
+	 *  This mutex must be locked before calling any FAM function
+	 *  (when not having the Mailbox::monitor_mutex_). To call
+	 *  FAMOpen() or FAMClose() and change the value of
+	 *  Local::fam_is_open_ the Mailbox::monitor_mutex_ must be
+	 *  locked. For calling functions like FAMNextEvent() it is
+	 *  sufficient to have the Mailbox::monitor_mutex_, so others with
+	 *  this mutex can call functions like FAMCancelMonitor().
+	 */
+	GMutex          *fam_mutex_;
 
 public:
 	// ========================================================================
