@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: mailbox.cc,v $
-// Revision      : $Revision: 1.76 $
-// Revision date : $Date: 2005/04/01 13:24:49 $
+// Revision      : $Revision: 1.79 $
+// Revision date : $Date: 2005/06/23 20:11:48 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -35,6 +35,7 @@
 #include "file.h"
 #include "maildir.h"
 #include "mh.h"
+#include "mh_sylpheed.h"
 #include "imap4.h"
 #include "pop3.h"
 #include "apop.h"
@@ -181,6 +182,45 @@ Mailbox::read (gboolean value)
 	g_mutex_unlock (mutex_);
 }
 
+/**
+ *  Return the standard port of the given mail protocol {\em protocol}. If
+ *  an invalid protocol is given zero is returned. This is also the case if
+ *  autodetection (for protocol or authentication is given).
+ *
+ *  @param  protocol  Protocol identifier
+ *  @param  auth      Method of authentication
+ *  @param  strict    If false the following combinations are also allowed:
+ *                    POP3 and APOP authentication. This is needed for
+ *                    displaying the correct port in the preferences dialog
+ *                    before all the values are correctly set. The default
+ *                    value is true.
+ *  @return           Standard port for the given combination of {\em protocol}
+ *                    and {\em use_ssl} or zero
+ */
+guint 
+Mailbox::standard_port (guint protocol, guint auth, gboolean strict)
+{
+	if (!strict && (protocol == PROTOCOL_POP3) && (auth == AUTH_APOP))
+		protocol = PROTOCOL_APOP;
+	switch (auth) {
+	case AUTH_AUTODETECT:
+	case AUTH_NONE:
+		return 0;
+	case AUTH_APOP:
+		return ((protocol == PROTOCOL_APOP) ? 110 : 0);
+	case AUTH_CERTIFICATE:
+	case AUTH_SSL:
+		if (protocol == PROTOCOL_IMAP4)
+			return 993;
+		return ((protocol == PROTOCOL_POP3) ? 995 : 0);
+	case AUTH_USER_PASS:
+		if (protocol == PROTOCOL_IMAP4)
+			return 143;
+		return ((protocol == PROTOCOL_POP3) ? 110 : 0);
+	}
+	return 0;
+}
+
 /**
  *  This function is called when an option is changed that has the
  *  OPTFLG_CHANGE flag set.
@@ -225,26 +265,9 @@ Mailbox::option_changed (Option *option)
 		|| (option->name() == "authentication")) {
 		guint newport = 0;
 
-		// Standard ports
-		if (!value_bool ("use_other_port")) {
-			guint auth = authentication();
-			switch (protocol ()) {
-			case PROTOCOL_IMAP4:
-				newport = (auth == AUTH_USER_PASS) ? 143 : 993;
-				break;
-			case PROTOCOL_POP3:
-				newport = (auth == AUTH_USER_PASS) ? 110 : 995;
-				break;
-			case PROTOCOL_APOP:
-				newport = (auth == AUTH_APOP) ? 110 : 995;
-				break;
-			default:
-				break;
-			}
-			if (auth == AUTH_AUTODETECT)
-				newport = 0;
-		}
-		// User given port
+		// Standard port or user given port?
+		if (!value_bool ("use_other_port"))
+			newport = standard_port (protocol(), authentication());
 		else
 			newport = value_uint ("other_port") % 65536;
 
@@ -486,40 +509,40 @@ Mailbox *
 Mailbox::lookup_local (Mailbox &oldmailbox)
 {
 	Mailbox *mailbox = NULL;
-	const gchar *address = oldmailbox.address().c_str();
-	gchar *base = g_path_get_basename (address);
+	std::string addr = oldmailbox.address ();
+	std::string base = path_get_basename (addr);
 
 	// Is it a directory?
-	if (g_file_test (address, G_FILE_TEST_IS_DIR)) {
-		gchar *mh_seq = g_build_filename (address, ".mh_sequences", NULL);
-		gchar *md_new = g_build_filename (address, "new", NULL);
+	if (g_file_test (addr.c_str(), G_FILE_TEST_IS_DIR)) {
+		std::string file_new = add_file_to_path (addr, "new");
+		std::string file_seq = add_file_to_path (addr, ".mh_sequences");
+		std::string file_syl = add_file_to_path (addr,".sylpheed_mark");
 
-		if (g_file_test (mh_seq, G_FILE_TEST_IS_REGULAR))
+		if (g_file_test (file_seq.c_str(), G_FILE_TEST_IS_REGULAR))
 			mailbox = new Mh (oldmailbox);
-		else if (std::string(base) == "new")
+		if (g_file_test (file_syl.c_str(), G_FILE_TEST_IS_REGULAR))
+			mailbox = new Mh_Sylpheed (oldmailbox);
+		else if (base == "new")
 			mailbox = new Maildir (oldmailbox);
-		else if (g_file_test (md_new, G_FILE_TEST_IS_DIR)) {
+		else if (g_file_test (file_new.c_str(), G_FILE_TEST_IS_DIR)) {
 			mailbox = new Maildir (oldmailbox);
-			mailbox->address (md_new);
+			mailbox->address (file_new);
 		}
-
-		g_free (mh_seq);
-		g_free (md_new);
 	}
 	// Is it a file?
-	else if (g_file_test (address, (G_FILE_TEST_EXISTS))) {
-		if (std::string(base) == ".mh_sequences") {
+	else if (g_file_test (addr.c_str(), G_FILE_TEST_EXISTS)) {
+		if (base == ".mh_sequences") {
 			mailbox = new Mh (oldmailbox);
-			gchar *dirname = g_path_get_dirname (address);
-			if (dirname)
-				mailbox->address (dirname);
-			g_free (dirname);
+			mailbox->address (path_get_dirname (addr));
+		}
+		else if (base == ".sylpheed_mark") {
+			mailbox = new Mh_Sylpheed (oldmailbox);
+			mailbox->address (path_get_dirname (addr));
 		}
 		else
 			mailbox = new File (oldmailbox);
 	}
 
-	g_free(base);
 	return mailbox;
 }
 
