@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-applet-gnome.cc,v $
-// Revision      : $Revision: 1.6 $
-// Revision date : $Date: 2005/03/21 15:33:09 $
+// Revision      : $Revision: 1.6.2.1 $
+// Revision date : $Date: 2005/10/06 18:43:34 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -165,7 +165,7 @@ AppletGnome::dock (GtkWidget *applet)
  
 	panel_applet_setup_menu_from_file (PANEL_APPLET (applet),
 									   NULL,
-									   "GNOME_gnubiffApplet.xml",
+									   GNUBIFF_UIDIR"/GNOME_gnubiffApplet.xml",
 									   NULL,
 									   gnubiffMenuVerbs,
 									   this);
