@@ -1,6 +1,6 @@
 // ========================================================================
 // gnubiff -- a mail notification program
-// Copyright (c) 2000-2004 Nicolas Rougier
+// Copyright (c) 2000-2005 Nicolas Rougier
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-applet-gtk.cc,v $
-// Revision      : $Revision: 1.1 $
-// Revision date : $Date: 2004/10/06 13:21:57 $
+// Revision      : $Revision: 1.8 $
+// Revision date : $Date: 2005/03/31 16:05:19 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -29,9 +29,7 @@
 // -*- mode:C++; tab-width:4; c-basic-offset:4; indent-tabs-mode:nil -*-
 // ========================================================================
 
-#ifdef HAVE_CONFIG_H
-#   include <config.h>
-#endif
+#include "support.h"
 
 #include <sstream>
 #include <cstdio>
@@ -42,7 +40,6 @@
 #include "ui-applet-gtk.h"
 #include "ui-popup.h"
 #include "mailbox.h"
-#include "nls.h"
 #include "gtk_image_animation.h"
 
 
@@ -53,48 +50,75 @@ extern "C" {
 							  GdkEventCrossing *event,
 							  gpointer data)
 	{
-		((AppletGtk *) data)->tooltip_update ();
+		if (data)
+			((AppletGtk *) data)->tooltip_update ();
+		else
+			unknown_internal_error ();
 	}
 
 	gboolean APPLET_GTK_on_button_press (GtkWidget *widget,
 										 GdkEventButton *event,
 										 gpointer data)
 	{
-		return ((AppletGtk *) data)->on_button_press (event);
+		if (data)
+			return ((AppletGtk *) data)->on_button_press (event);
+		else
+			unknown_internal_error ();
+		return false;
 	}
 
-	void APPLET_GTK_on_menu_mail_app (GtkWidget *widget,
-									  gpointer data)
+	void APPLET_GTK_on_menu_command (GtkWidget *widget,
+									 gpointer data)
 	{
-		((AppletGtk *) data)->on_menu_mail_app ();
+		if (data)
+			((AppletGtk *) data)->on_menu_command ();
+		else
+			unknown_internal_error ();
 	}
 
 	void APPLET_GTK_on_menu_mark (GtkWidget *widget,
 								  gpointer data)
 	{
-		((AppletGtk *) data)->on_menu_mark ();
+		if (data)
+			((AppletGtk *) data)->on_menu_mark ();
+		else
+			unknown_internal_error ();
 	}
+
 	void APPLET_GTK_on_menu_preferences (GtkWidget *widget,
 										 gpointer data)
 	{
-		((AppletGtk *) data)->on_menu_preferences ();
+		if (data)
+			((AppletGtk *) data)->on_menu_preferences ();
+		else
+			unknown_internal_error ();
 	}
+
 	void APPLET_GTK_on_menu_about (GtkWidget *widget,
 								   gpointer data)
 	{
-		((AppletGtk *) data)->on_menu_about ();
+		if (data)
+			((AppletGtk *) data)->on_menu_about ();
+		else
+			unknown_internal_error ();
 	}
 	
 	void APPLET_GTK_on_menu_quit (GtkWidget *widget,
 								  gpointer data)
 	{
-		((AppletGtk *) data)->on_menu_quit ();
+		if (data)
+			((AppletGtk *) data)->on_menu_quit ();
+		else
+			unknown_internal_error ();
 	}
 
 	void APPLET_GTK_on_hide_about (GtkWidget *widget,
 								   gpointer data)
 	{
-		((AppletGtk *) data)->on_hide_about ();
+		if (data)
+			((AppletGtk *) data)->on_hide_about ();
+		else
+			unknown_internal_error ();
 	}
 }
 
@@ -114,19 +138,22 @@ AppletGtk::create (void)
 	GUI::create();
 	GtkImageAnimation *anim = new GtkImageAnimation (GTK_IMAGE(get("image")));
 	g_object_set_data (G_OBJECT(get("image")), "_animation_", anim);
-	anim->open (biff_->biff_nomail_image_.c_str());
+	anim->open (biff_->value_string ("nomail_image"));
 	anim->start();
+	update();
 	return true;
 }
 
 
 void
-AppletGtk::update (void)
+AppletGtk::update (gboolean no_popup)
 {
 	// Is there another update going on ?
 	if (!g_mutex_trylock (update_mutex_))
 		return;
 
+	Applet::update(no_popup);
+
 	std::string text;
 	guint unread = unread_markup (text);
 
@@ -134,26 +161,26 @@ AppletGtk::update (void)
 	GtkImageAnimation *anim = (GtkImageAnimation *) g_object_get_data (G_OBJECT(get("image")), "_animation_");
 	if (unread > 0) {
 		gtk_window_set_title (GTK_WINDOW(get("dialog")), _("New mail"));
-		anim->open (biff_->biff_newmail_image_.c_str());
+		anim->open (biff_->value_string ("newmail_image"));
 		anim->start();
-		if (!biff_->biff_use_newmail_image_)
+		if (!biff_->value_bool ("use_newmail_image"))
 			hide();
 		else
 			show ();
-		if (!biff_->biff_use_newmail_text_)
+		if (!biff_->value_bool ("use_newmail_text"))
 			gtk_widget_hide (get("unread"));
 		else
 			gtk_widget_show (get("unread"));
 	}
 	else {
 		gtk_window_set_title (GTK_WINDOW(get("dialog")), _("No mail"));
-		anim->open (biff_->biff_nomail_image_.c_str());
+		anim->open (biff_->value_string ("nomail_image"));
 		anim->start();
-		if (!biff_->biff_use_nomail_image_)
+		if (!biff_->value_bool ("use_nomail_image"))
 			hide();
 		else
 			show ();
-		if (!biff_->biff_use_nomail_text_)
+		if (!biff_->value_bool ("use_nomail_text"))
 			gtk_widget_hide (get("unread"));
 		else
 			gtk_widget_show (get("unread"));
@@ -174,8 +201,9 @@ AppletGtk::update (void)
 
 	// Update window manager decorations
 	gboolean decorated = gtk_window_get_decorated (GTK_WINDOW(get("dialog")));
-	if (decorated != biff_->biff_is_decorated_)
-		gtk_window_set_decorated (GTK_WINDOW(get("dialog")), biff_->biff_is_decorated_);
+	if (decorated != biff_->value_bool ("applet_use_decoration"))
+		gtk_window_set_decorated (GTK_WINDOW(get("dialog")),
+								  biff_->value_bool ("applet_use_decoration"));
 	tooltip_update();
 	show();
 
@@ -190,18 +218,23 @@ AppletGtk::show (std::string name)
 	for (unsigned int i=0; i<biff_->size(); i++)
 		unread += biff_->mailbox(i)->unreads();
 
-	if ((unread > 0) && (!biff_->biff_use_newmail_image_))
+	if ((unread > 0) && (!biff_->value_bool ("use_newmail_image")))
 		return;
-	else if (!biff_->biff_use_nomail_image_)
+	else if (!biff_->value_bool ("use_nomail_image"))
 		return;
 
+	GtkWindow *dialog=GTK_WINDOW(get("dialog"));
 	gtk_widget_show (get("dialog"));
-	if (biff_->biff_use_geometry_)
-		gtk_window_parse_geometry (GTK_WINDOW(get("dialog")), biff_->biff_geometry_.c_str());
+	if (biff_->value_bool ("applet_use_geometry"))
+		gtk_window_parse_geometry (dialog, biff_->value_gchar ("applet_geometry"));
+	if (biff_->value_bool ("applet_be_sticky"))
+		gtk_window_stick (dialog);
+	else
+		gtk_window_unstick (dialog);
+	gtk_window_set_keep_above(dialog, biff_->value_bool ("applet_keep_above"));
+	gtk_window_set_skip_pager_hint (dialog,!biff_->value_bool("applet_pager"));
 }
 
-
-
 void
 AppletGtk::tooltip_update (void)
 {
@@ -213,41 +246,43 @@ AppletGtk::tooltip_update (void)
 gboolean
 AppletGtk::on_button_press (GdkEventButton *event)
 {
-	// Double left click : start mail app
+	// Double left click: start mail app
 	if ((event->type == GDK_2BUTTON_PRESS) && (event->button == 1))
-		on_menu_mail_app ();
+		on_menu_command ();
 
-	// Single left click : force mail check
-	else if (event->button == 1)
-		watch();
-
-	// Single middle click : mark mails as read
-	else if (event->button == 2) {
-		for (unsigned int i=0; i<biff_->size(); i++)
-			biff_->mailbox(i)->mark_all();
+	// Single left click: force mail check
+	else if (event->button == 1) {
 		force_popup_ = true;
-		biff_->popup()->hide();
-		biff_->applet()->process();
-		biff_->applet()->update();
+		update ();
 	}
 
-	// Single right click : popup menu
+	// Single middle click: mark mails as read
+	else if (event->button == 2) {
+		for (unsigned int i=0; i<biff_->size(); i++)
+			biff_->mailbox(i)->read();
+		force_popup_ = true;
+		biff_->popup()->hide();
+		update();
+	}
+
+	// Single right click: popup menu
 	else if (event->button == 3) {
-		if (biff_->mail_app_.empty())
-			gtk_widget_set_sensitive (get("menu_start_mailapp"), false);
+		if (biff_->value_bool ("use_double_command"))
+			gtk_widget_set_sensitive (get("menu_start_command"), true);
 		else
-			gtk_widget_set_sensitive (get("menu_start_mailapp"), true);
-		gtk_menu_popup (GTK_MENU(get("menu")), NULL, NULL, NULL, NULL, event->button, event->time);
+			gtk_widget_set_sensitive (get("menu_start_command"), false);
+		gtk_menu_popup (GTK_MENU(get("menu")), NULL, NULL, NULL, NULL,
+						event->button, event->time);
 	}
 	return true;
 }
 
 
 void
-AppletGtk::on_menu_mail_app (void)
+AppletGtk::on_menu_command (void)
 {
-	if (!biff_->mail_app_.empty()) {
-		std::string command = biff_->mail_app_ + " &";
+	if ((biff_->value_bool ("use_double_command")) && (!biff_->value_string ("double_command").empty())) {
+		std::string command = biff_->value_string ("double_command") + " &";
 		system (command.c_str());
 	}
 }
@@ -255,7 +290,6 @@ AppletGtk::on_menu_mail_app (void)
 void
 AppletGtk::on_menu_preferences (void)
 {
-	biff_->applet()->watch_off();
 	biff_->popup()->hide();
 	biff_->preferences()->show();
 }
@@ -264,11 +298,10 @@ void
 AppletGtk::on_menu_mark (void)
 {
 	for (unsigned int i=0; i<biff_->size(); i++)
-		biff_->mailbox(i)->mark_all();
+		biff_->mailbox(i)->read ();
 	force_popup_ = true;
 	biff_->popup()->hide();
-	biff_->applet()->process();
-	biff_->applet()->update();
+	update();
 }
 
 void
@@ -282,10 +315,6 @@ AppletGtk::on_menu_about (void)
 {
 	biff_->popup()->hide();
 	biff_->preferences()->hide();
-	std::string package = "<span size=\"xx-large\"><b>";
-	package += PACKAGE_STRING;
-	package += "</b></span>";
-	gtk_label_set_markup (GTK_LABEL (get("about_version")), package.c_str());
 	GUI::show ("about");
 }
 
