@@ -19,8 +19,8 @@
 // ========================================================================
 //
 // File          : $RCSfile: ui-popup.h,v $
-// Revision      : $Revision: 1.1 $
-// Revision date : $Date: 2004/10/06 13:21:57 $
+// Revision      : $Revision: 1.6 $
+// Revision date : $Date: 2005/03/08 11:55:12 $
 // Author(s)     : Nicolas Rougier
 // Short         : 
 //
@@ -35,8 +35,10 @@
 #ifdef HAVE_CONFIG_H
 #   include <config.h>
 #endif
+#include "decoding.h"
 #include "gui.h"
 #include "biff.h"
+#include "mailbox.h"
 
 enum {
 	COLUMN_NAME = 0,
@@ -44,22 +46,17 @@ enum {
 	COLUMN_SENDER,
 	COLUMN_SUBJECT,
 	COLUMN_DATE,
-	COLUMN_FONT_COLOR,
-//	COLUMN_BACK_COLOR,
-	COLUMN_HEADER,
+	COLUMN_MAILID,
 	COLUMNS
 };
 
-#define BASE64(c) (index_64[(unsigned char)(c) & 0x7F])
-
-
-class Popup : public GUI {
+class Popup : public GUI, public Decoding {
 
 protected:
 	class Biff *		biff_;				// Biff owner
 	gint				poptag_;			// Tag for pop timer
 	static GStaticMutex	timer_mutex_;		// Mutex for timer tag access
-	header *			selected_header_;	// Current selected header
+	Header				selected_header_;	// Current selected header
 	GtkTreeSelection *	tree_selection_;	// Current tree selection
 	gboolean			consulting_;		// Tag to know if we're consulting a mail
 	gint				x_;					// Last mouse x position known
@@ -84,13 +81,6 @@ protected:
 	void on_enter (GdkEventCrossing *event);
 	void on_leave (GdkEventCrossing *event);
 	void on_select (GtkTreeSelection *selection);
-
-private:
-	/* util */
-	gchar *parse_header (std::string text);
-	int decode_quoted (const gchar *buftodec, gchar *decbuf);
-	int decode_base64 (gchar *src, gchar *dest);
-	gchar *convert (std::string text, std::string charset);
 };
 
 #endif
